The Gro US Crop API Client is a Python library to help with the discovery and retrieval of data series related to US crops.

The library is written on top of the [Gro Python Client API](https://github.com/gro-intelligence/api-client)
and offers a set of convenience methods and constants to make the use of the Gro API faster and simpler.

The use of the Gro US Crop API Client requires a Gro account with API access.
Visit our [website](https://gro-intelligence.com/platform/api) for more information.
